cole Library

cole Library Reference Manual
Prev |  | Next

# Chapter 3. cole Library

This is the documentation autogenerated from the source code. It have the cole API for this release, and some internal structures and internal calls.

Note: what Microsoft calls `stream` is called `file` in this project, `storage` is called `directory` and `docfile` (a Structured Storage file) is called `filesystem`.

The files in the subdirectory `examples` in the source code show the complete public API in action. Briefly, if you know how to use the `stdio.h` ANSI C calls, cole API will be very easy for you.

If you use `autoconf` in your own proyect, the included file `cole.m4` may be useful for you. It contains the m4 macro AM_PATH_COLE that detect the presense or ausence of the cole library in the system being configured. To use it:

1. If cole is not installed in your system (i.e. `aclocal` can't find `cole.m4`), add the content of `cole.m4` to your own `acinclude.m4` file (create it in case you haven't one).

2. Add a line like `AM_PATH_COLE(2.0.0, [LIBS="$LIBS $COLE_LIBS" CFLAGS="$CFLAGS $COLE_CFLAGS"])` to your `configure.in` file. Here we are requesting for cole release 2.0.0, and adding the necessary flags to LIBS and CFLAGS.

3. Run `aclocal` to generate the file `aclocal.m4`. This file will have many m4 macros, incluiding the cole m4 macro, and

4. Run `autoconf` to generate the script `configure`.

Many API calls take an argument at the end called `colerrno`. If it's not NULL and the call failed, it store the error code for fail, if any (if the call was successfully ended, its value is not modified).

Prev | Home | Next
How to compile cole |  | API